@@ -1,4 +1,4 @@
-from xflask.common import *
+from xflask.common import get_xflask
 
 def get_current_user():
     auth_manager = get_xflask().auth_manager
